How to export cf values to latex
cf_field_to_latex(cf_field, xview, unlocked)
Arguments
- cf_field
A cf_field object. This is like a rule, but with the computed
colour values. It usually maps one-to-one to a CSS field.
- xview
A data frame with the columns to be printed and rows filtered
- unlocked
A logical matrix of cells unlocked (that can still be modified by further
rules).
Value
A list with two character matrices named before and after. Both
of these matrices must be of the same size as xview.