A condformat_tbl object is a data frame with attributes regarding
the formatting of their cells, that can be viewed when the condformat_tbl
object is printed.
condformat(x)The condformat_tbl object. This object can be piped to apply
conditional formatting rules. It can also be used as a conventional
data frame.
The condformat_tbl print method generates an htmlTable, to be
viewed using the 'RStudio Viewer' or an 'HTML browser', as available.
data(iris)
cf <- condformat(iris[1:5,])
if (FALSE) { # \dontrun{
print(cf)
} # }
cf <- condformat(iris[1:5,]) |> rule_fill_gradient(Sepal.Length)
if (FALSE) { # \dontrun{
print(cf)
} # }
cf <- condformat(iris[1:5,]) |>
rule_fill_discrete(Sepal.Length, expression=Sepal.Width > 2)
if (FALSE) { # \dontrun{
print(cf)
} # }