condformat2excel: Writes the table to an Excel workbook

View source: R/render_xlsx.R

condformat2excelR Documentation

Writes the table to an Excel workbook

Description

Requires the openxlsx package (install.packages("openxlsx")).

Usage

condformat2excel(
  x,
  filename,
  sheet_name = "Sheet1",
  overwrite_wb = FALSE,
  overwrite_sheet = TRUE
)

Arguments

x

A condformat_tbl object

filename

The xlsx file name.

sheet_name

The name of the sheet where the table will be written

overwrite_wb

logical to overwrite the whole workbook file

overwrite_sheet

logical to overwrite the sheet

See Also

condformat2excelsheet(), to write into a worksheet of an openxlsx workbook you're building yourself, so you can add more sheets or apply extra openxlsx formatting before saving.


condformat documentation built on July 10, 2026, 1:07 a.m.