Fills the background color of a column using a gradient based on the values given by an expression
rule_fill_gradient(
x,
columns,
expression,
low = "#132B43",
high = "#56B1F7",
space = "Lab",
na.value = "#7F7F7F",
limits = NA,
lockcells = FALSE
)A condformat object, typically created with condformat()
A character vector with column names to be coloured. Optionally
tidyselect::language() can be used.
an expression to be evaluated with the data.
It should evaluate to a numeric vector,
that will be used to determine the colour gradient level.
When columns selects more than one column, the expression is
evaluated once per column, with the .col pronoun bound to that
column's own values (and limits, if not given, computed from
that column alone). If omitted, it defaults to .col.
colour for low end of gradient.
colour for high end of gradient.
colour space in which to calculate gradient. Must be "Lab" - other values are deprecated.
fill color for missing values
range of limits that the gradient should cover
logical value determining if no further rules should be applied to the affected cells.
The condformat_tbl object, with the added formatting information
data(iris)
cf <- condformat(iris[c(1:5, 70:75, 120:125), ]) |>
rule_fill_gradient(Sepal.Length) |>
rule_fill_gradient(Species, expression=Sepal.Length - Sepal.Width)
if (FALSE) { # \dontrun{
print(cf)
} # }
cf <- condformat(iris[c(1:5, 70:75, 120:125), ]) |>
rule_fill_gradient("Petal.Length") |>
rule_fill_gradient(starts_with("Sepal"), expression=Sepal.Length - Sepal.Width)
if (FALSE) { # \dontrun{
print(cf)
} # }